pygeodesy.solveBase._SolveCapsBase

Package pygeodesy :: Module solveBase :: Class _SolveCapsBase |
[frames] | no frames]

# Class _SolveCapsBase

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
        karney._CapsBase --+
                           |
                          _SolveCapsBase

Known Subclasses:
  - _SolveBase
  - , geodesici.Intersectool

(NTERNAL) Base class for `_SolveBase` and `_LineSolveBase`.

Instance Methods
invokat(self, *prefix) Get and set the invokation number `"@"` prefix (`str`). |
invoke(self, *options, **stdin) Invoke the `Solve` executable and return the result. |
linelimit(self, *limit) Set and get the print line length limit. |
Inherited from `karney._CapsBase`: `caps_` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr`, `toStr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables
Inherited from `karney._CapsBase`: `ALL`, `AREA`, `AZIMUTH`, `DISTANCE`, `DISTANCE_IN`, `EMPTY`, `GEODESICSCALE`, `LATITUDE`, `LINE_CAPS`, `LINE_OFF`, `LONGITUDE`, `LONG_UNROLL`, `NONFINITONAN`, `REDUCEDLENGTH`, `STANDARD`, `STANDARD_LINE`

Properties
| a Get the ellipsoid's equatorial radius, semi-axis (`meter`).
| b Get the ellipsoid's polar radius, semi-axis (`meter`).
| datum Get the datum (`Datum`).
| Exact Get the Solve's `exact` setting (`bool`).
| ellipsoid Get the ellipsoid (`Ellipsoid`).
| flattening Get the `ellipsoid`'s flattening (`scalar`), (a - b) / a, `0` for spherical, negative for prolate.
| f Get the `ellipsoid`'s flattening (`scalar`), (a - b) / a, `0` for spherical, negative for prolate.
| invokation Get the most recent `Solve` invokation number (`int`).
| prec Get the precision, number of (decimal) digits (`int`).
| status Get the most recent `Solve` return code (`int`, `str`) or `None`.
| verbose Get the `verbose` option (`bool`).
| version Get the result of `"GeodSolve --version"` or `"RhumbSolve --version"`.
Inherited from `karney._CapsBase`: `caps`, `debug` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### invokat (self, *prefix) |
Get and set the invokation number `"@"` prefix (`str`). Returns: Previous prefix (`str`).

### invoke (self, *options, **stdin) |
Invoke the `Solve` executable and return the result. Arguments: `options` - No, one or several `Solve` command line options (`str`s). `stdin` - Optional input to pass to `Solve.stdin` (`str`). Returns: The `Solve.stdout` and `.stderr` output (`str`). Raises: `GeodesicError` - On any error, including a non-zero return code from `GeodSolve`. `RhumbError` - On any error, including a non-zero return code from `RhumbSolve`. Note: The `Solve` return code is in property status.

### linelimit (self, *limit) |
Set and get the print line length limit. Arguments: `limit` - New line limit (`int`) or `0` or `None` for unlimited. Returns: Teh previous limit (`int`).

Property Details

### a Get the ellipsoid's equatorial radius, semi-axis (`meter`). Get method: a(self) - Get the ellipsoid's equatorial radius, semi-axis (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### b Get the ellipsoid's polar radius, semi-axis (`meter`). Get method: b(self) - Get the ellipsoid's polar radius, semi-axis (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### datum Get the datum (`Datum`). Get method: datum(self) - Get the datum (`Datum`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### Exact Get the Solve's `exact` setting (`bool`). Get method: Exact(self) - Get the Solve's `exact` setting (`bool`). Set method: Exact(self, Exact) - Set the Solve's `exact` setting (`bool`), if `True` use exact version.

### ellipsoid Get the ellipsoid (`Ellipsoid`). Get method: ellipsoid(self) - Get the ellipsoid (`Ellipsoid`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### flattening Get the `ellipsoid`'s flattening (`scalar`), (a - b) / a, `0` for spherical, negative for prolate. Get method: flattening(self) - Get the `ellipsoid`'s flattening (`scalar`), (a - b) / a, `0` for spherical, negative for prolate. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### f Get the `ellipsoid`'s flattening (`scalar`), (a - b) / a, `0` for spherical, negative for prolate. Get method: flattening(self) - Get the `ellipsoid`'s flattening (`scalar`), (a - b) / a, `0` for spherical, negative for prolate. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### invokation Get the most recent `Solve` invokation number (`int`). Get method: invokation(self) - Get the most recent `Solve` invokation number (`int`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### prec Get the precision, number of (decimal) digits (`int`). Get method: prec(self) - Get the precision, number of (decimal) digits (`int`). Set method: prec(self, prec) - Set the precision for `angles` in `degrees`, like `lat`, `lon`, `azimuth` and `arc` in number of decimal digits (`int`, `0`.. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### status Get the most recent `Solve` return code (`int`, `str`) or `None`. Get method: status(self) - Get the most recent `Solve` return code (`int`, `str`) or `None`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### verbose Get the `verbose` option (`bool`). Get method: verbose(self) - Get the `verbose` option (`bool`). Set method: verbose(self, verbose) - Set the `verbose` option (`bool`), `True` prints a message around each `RhumbSolve` invokation.

### version Get the result of `"GeodSolve --version"` or `"RhumbSolve --version"`. Get method: version(self) - Get the result of `"GeodSolve --version"` or `"RhumbSolve --version"`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.